"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TriggerTypeEnum(str, Enum):
    r"""The type of the trigger"""

    EVENT = "event"
