"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .channeltypeenum import ChannelTypeEnum
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class ChannelPreferenceTypedDict(TypedDict):
    type: ChannelTypeEnum
    r"""Channel type through which the message is sent"""
    enabled: bool
    r"""If channel is enabled or not"""


class ChannelPreference(BaseModel):
    type: ChannelTypeEnum
    r"""Channel type through which the message is sent"""

    enabled: bool
    r"""If channel is enabled or not"""
