"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .integrationresponsedto import (
    IntegrationResponseDto,
    IntegrationResponseDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IntegrationsControllerListIntegrationsRequestTypedDict(TypedDict):
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class IntegrationsControllerListIntegrationsRequest(BaseModel):
    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class IntegrationsControllerListIntegrationsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[IntegrationResponseDtoTypedDict]


class IntegrationsControllerListIntegrationsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[IntegrationResponseDto]
