"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .channelpreference import ChannelPreference, ChannelPreferenceTypedDict
from novu_py.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class UpdateSubscriberGlobalPreferencesRequestDtoTypedDict(TypedDict):
    enabled: NotRequired[bool]
    r"""Enable or disable the subscriber global preferences."""
    preferences: NotRequired[List[ChannelPreferenceTypedDict]]
    r"""The subscriber global preferences for every ChannelTypeEnum."""


class UpdateSubscriberGlobalPreferencesRequestDto(BaseModel):
    enabled: Optional[bool] = None
    r"""Enable or disable the subscriber global preferences."""

    preferences: Optional[List[ChannelPreference]] = None
    r"""The subscriber global preferences for every ChannelTypeEnum."""
