"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class RenameTopicRequestDtoTypedDict(TypedDict):
    name: str
    r"""User defined custom name and provided by the user to rename the topic."""


class RenameTopicRequestDto(BaseModel):
    name: str
    r"""User defined custom name and provided by the user to rename the topic."""
