"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class DataBooleanDtoTypedDict(TypedDict):
    data: bool


class DataBooleanDto(BaseModel):
    data: bool
