"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class TriggerReservedVariableResponseType(str, Enum):
    r"""The type of the reserved variable"""

    TENANT = "tenant"
    ACTOR = "actor"


class TriggerReservedVariableResponseTypedDict(TypedDict):
    type: TriggerReservedVariableResponseType
    r"""The type of the reserved variable"""
    variables: List[str]
    r"""The reserved variables of the trigger"""


class TriggerReservedVariableResponse(BaseModel):
    type: TriggerReservedVariableResponseType
    r"""The type of the reserved variable"""

    variables: List[str]
    r"""The reserved variables of the trigger"""
