"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .preference import Preference, PreferenceTypedDict
from .templateresponse import TemplateResponse, TemplateResponseTypedDict
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class UpdateSubscriberPreferenceResponseDtoTypedDict(TypedDict):
    template: TemplateResponseTypedDict
    r"""The workflow information and if it is critical or not"""
    preference: PreferenceTypedDict
    r"""The preferences of the subscriber regarding the related workflow"""


class UpdateSubscriberPreferenceResponseDto(BaseModel):
    template: TemplateResponse
    r"""The workflow information and if it is critical or not"""

    preference: Preference
    r"""The preferences of the subscriber regarding the related workflow"""
