"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .preferencechannels import PreferenceChannels, PreferenceChannelsTypedDict
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class PreferenceTypedDict(TypedDict):
    enabled: bool
    r"""Sets if the workflow is fully enabled for all channels or not for the subscriber."""
    channels: PreferenceChannelsTypedDict
    r"""Subscriber preferences for the different channels regarding this workflow"""


class Preference(BaseModel):
    enabled: bool
    r"""Sets if the workflow is fully enabled for all channels or not for the subscriber."""

    channels: PreferenceChannels
    r"""Subscriber preferences for the different channels regarding this workflow"""
