"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FailedAssignmentsDtoTypedDict(TypedDict):
    not_found: NotRequired[List[str]]
    r"""List of subscriber IDs that were not found"""


class FailedAssignmentsDto(BaseModel):
    not_found: Annotated[Optional[List[str]], pydantic.Field(alias="notFound")] = None
    r"""List of subscriber IDs that were not found"""
