"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .preference import Preference, PreferenceTypedDict
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class UpdateSubscriberPreferenceGlobalResponseDtoTypedDict(TypedDict):
    preference: PreferenceTypedDict
    r"""The preferences of the subscriber regarding the related workflow"""


class UpdateSubscriberPreferenceGlobalResponseDto(BaseModel):
    preference: Preference
    r"""The preferences of the subscriber regarding the related workflow"""
