"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class AddSubscribersRequestDtoTypedDict(TypedDict):
    subscribers: List[str]
    r"""List of subscriber identifiers that will be associated to the topic"""


class AddSubscribersRequestDto(BaseModel):
    subscribers: List[str]
    r"""List of subscriber identifiers that will be associated to the topic"""
