"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PreferenceChannelsTypedDict(TypedDict):
    email: NotRequired[bool]
    sms: NotRequired[bool]
    in_app: NotRequired[bool]
    chat: NotRequired[bool]
    push: NotRequired[bool]


class PreferenceChannels(BaseModel):
    email: Optional[bool] = None

    sms: Optional[bool] = None

    in_app: Optional[bool] = None

    chat: Optional[bool] = None

    push: Optional[bool] = None
