"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class ActivityStatsResponseDtoTypedDict(TypedDict):
    weekly_sent: float
    monthly_sent: float


class ActivityStatsResponseDto(BaseModel):
    weekly_sent: Annotated[float, pydantic.Field(alias="weeklySent")]

    monthly_sent: Annotated[float, pydantic.Field(alias="monthlySent")]
