"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class RenameTopicResponseDtoTypedDict(TypedDict):
    organization_id: str
    environment_id: str
    key: str
    name: str
    subscribers: List[str]
    id: NotRequired[str]


class RenameTopicResponseDto(BaseModel):
    organization_id: Annotated[str, pydantic.Field(alias="_organizationId")]

    environment_id: Annotated[str, pydantic.Field(alias="_environmentId")]

    key: str

    name: str

    subscribers: List[str]

    id: Annotated[Optional[str], pydantic.Field(alias="_id")] = None
